#
# spec file for package libt3widget
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libt3widget
%define lname	libt3widget2
Version:        1.2.2
Release:        1.8
Summary:        The Tilde terminal dialog toolkit
License:        GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://os.ghalkes.nl/t3/libt3widget.html

#Git-Clone:	https://github.com/gphalkes/t3widget
Source:         https://os.ghalkes.nl/dist/%name-%version.tar.bz2
Source2:        https://os.ghalkes.nl/dist/%name-%version.tar.bz2.sig
Source3:        %name.keyring
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  gpm-devel
BuildRequires:  libtool
BuildRequires:  libunistring-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libt3key) >= 0.2.0
BuildRequires:  pkgconfig(libt3window) >= 0.4.0
BuildRequires:  pkgconfig(libtranscript) >= 0.2.2
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)

%description
The libt3widget library provides a C++ dialog toolkit. It provides
objects for dialogs and widgets like buttons, text fields, check
boxes etc., to facilitate easy construction of dialog based programs
for Unix-type terminals.

%package -n %lname
Summary:        The Tilde terminal dialog toolkit
Group:          System/Libraries

%description -n %lname
The libt3widget library provides a C++ dialog toolkit. It provides
objects for dialogs and widgets like buttons, text fields, check
boxes etc., to facilitate easy construction of dialog based programs
for Unix-type terminals.

%package devel
Summary:        Development files for libt3widget, a terminal dialog library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
The libt3widget library provides a C++ dialog toolkit. It provides
objects for dialogs and widgets like buttons, text fields, check
boxes etc., to facilitate easy construction of dialog based programs
for Unix-type terminals.

This subpackage contains libraries and header files for developing
applications that want to make use of libt3widget.

%prep
%autosetup -p1

%build
./configure --prefix="%_prefix" --libdir="%_libdir" --docdir="%_docdir/%name"
%make_build

%install
%make_install
find "%buildroot/%_libdir" -type f -name "*.la" -delete
%fdupes %buildroot/%_prefix

%post   -p /sbin/ldconfig -n %lname
%postun -p /sbin/ldconfig -n %lname

%files -n %lname
%_libdir/libt3widget.so.2*
%license COPYING

%files devel
%_includedir/t3widget/
%_libdir/libt3widget.so
%_libdir/pkgconfig/libt3widget.pc
%_libdir/libt3widget/
%_docdir/%name/
%exclude %_docdir/%name/COPYING

%changelog
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.2
  * Fix incorrect computation of the number of endchars in a
    text_line when the end of the line truncated a double-width
    character. This would cause a segmentation fault in the
    t3window library.
  * This release fixes a bug which makes Tilde crash on start up,
    due to a typo in a copy-assignment operator signature which
    causes an infinite recursion.
* Thu Dec 19 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0
  * This release provides several new features and bug fixes,
    among which:
  * Pressing ctrl+backspace will delete the previous word,
  * Extra navigation keys (+/- and arrows) for expander widgets.
  * Checkboxes can now have a third, indeterminate, state.
  * Frame resizing correctly redraws the frame.
  * This release changes the selection of binary attributes to
    make the distinction between explicitly unset and fallback
    from base attribute
* Thu Aug 22 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.0.6
  * This release makes the indent_selection and
    unindent_selection functions on edit_window_t behave exactly
    as pressing tab or shift-tab. This resolves a segmentation
    fault when calling these functions without a selected text.
* Mon Jan  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.0.3
  * Fixed: The indicator in list panes would disappear of screen
    when scrolling beyond the first page.
  * Fixed: The cursor position after undoing an unindent
    operation was set incorrectly.
  * Fixed: Bracketed paste mode was not handled correctly due to
    inadvertent setting of the EKEY_PROTECT bit.
  * The API has been overhauled to use more of the features of
    the C++11 standard.
  * Fixed: Unsplitting caused segmentation faults.
  * The connection to GPM remained open during suspend, making
    GPM useless for the duration of the suspend.
  * Prevent the mouse cursor from moving beyond the top of the
    screen while holding down the mouse button in GPM mode.
  * Ensure that the mouse cursor is visible when the holding down
    the mouse button in GPM mode.
  * Allow searching for empty strings using regular expressions.
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 0.5.2
  * Added an extra function for thread-safe termination of the main
    loop.
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 0.4.7
  * Fix crashes due to invisible widgets getting activated through hotkeys.
  * Fix read of uninitialized value.
  * Fix memory leaks in edit widget undo/redo.
* Mon Jul 21 2014 jengelh@inai.de
- Update to new upstream release 0.4.6
  * This release fixes the movement of cursor after inserting a tab
  and when pressing left or right when text is selected.
  Furthermore, it disallows pasting of values with filtered
  characters in text fields.
  * This release also fixes the movement of cursor after positioning
  the cursor with the mouse; a crash when clicking beyond the text
  in wrap mode; sanitization of directory names.
* Mon Feb  3 2014 jengelh@inai.de
- Update to new upstream release 0.4.4
  * This release fixes the drawing of the last line when text
  wrapping is enabled, and fixes problems with X11 copy/paste and
  handles trailing slashes and double slashes in directory names
  in the file dialog properly.
* Mon Jun 10 2013 jengelh@inai.de
- Initial package (version 0.4.2) for build.opensuse.org
